@@ -12,8 +12,7 @@ Usage example:
     >>> list(g.select(V(1).knows))
     [1]
     >>> g.store(V(2).knows(1))
-    >>> g.select(V(1).knows)\
-    ...     .intersection(V().knows(1)).first
+    >>> g.select(V(1).knows).intersection(V().knows(1)).first
     2
 """
 
