@@ -98,3 +98,16 @@ def get_one_relation(src, relation, dst):
     """
     statement = 'SELECT id FROM %s WHERE src = ? AND dst = ? LIMIT 1;'
     return statement % (relation), (src, dst)
+
+
+def compound_forwards_query(relation, query):
+    """
+    Select destionation nodes from a given relation
+    which source nodes include those in the SQL query.
+
+    :param relation: The relation.
+    :param query: An SQL query to be used as the
+    subquery.
+    """
+    statement = 'SELECT dst FROM %s WHERE src IN (%s)'
+    return statement % (relation, query)
