@@ -17,6 +17,7 @@ def graph():
         ]
     )
 
-    for x in c:
-        graph.store(x)
+    with graph.transaction() as tr:
+        for x in c:
+            tr.store(x)
     return graph
